@@ -232,13 +232,12 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     if type(description) == str:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
-                    loop = asyncio.new_event_loop()
-                    asyncio.set_event_loop(loop)
+
 
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
-                    loop.run_until_complete(self.peerConnections[id].setRemoteDescription(answer))
-                    loop.close()
+                    syncify_async_function(self.peerConnections[id].setRemoteDescription(answer))
+
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
